summaryrefslogtreecommitdiffstats
path: root/core
diff options
context:
space:
mode:
authorLibravatar rhysd <lin90162@yahoo.co.jp>2025-02-06 01:50:25 +0900
committerLibravatar rhysd <lin90162@yahoo.co.jp>2025-02-06 02:01:52 +0900
commitfcdf53afdee9cd12bf2e01c5f6e572859b9a3f96 (patch)
tree0f28b34b42e88db0dc379e3c3b8b6deb88192df2 /core
parent4bbb5cbc1f8b2a0ee8e09be18071368df3ba5bbd (diff)
downloadiced-fcdf53afdee9cd12bf2e01c5f6e572859b9a3f96.tar.gz
iced-fcdf53afdee9cd12bf2e01c5f6e572859b9a3f96.tar.bz2
iced-fcdf53afdee9cd12bf2e01c5f6e572859b9a3f96.zip
Set correct text size for text in preedit window
Diffstat (limited to 'core')
-rw-r--r--core/src/input_method.rs17
1 files changed, 12 insertions, 5 deletions
diff --git a/core/src/input_method.rs b/core/src/input_method.rs
index 4e8c383b..ab00b5af 100644
--- a/core/src/input_method.rs
+++ b/core/src/input_method.rs
@@ -1,5 +1,5 @@
//! Listen to input method events.
-use crate::Point;
+use crate::{Pixels, Point};
use std::ops::Range;
@@ -34,15 +34,20 @@ pub struct Preedit<T = String> {
pub content: T,
/// The selected range of the content.
pub selection: Option<Range<usize>>,
+ /// The text size of the content.
+ pub text_size: Option<Pixels>,
}
impl<T> Preedit<T> {
/// Creates a new empty [`Preedit`].
- pub fn new() -> Self
+ pub fn new(text_size: Option<impl Into<Pixels>>) -> Self
where
T: Default,
{
- Self::default()
+ Self {
+ text_size: text_size.map(Into::into),
+ ..Default::default()
+ }
}
/// Turns a [`Preedit`] into its owned version.
@@ -53,6 +58,7 @@ impl<T> Preedit<T> {
Preedit {
content: self.content.as_ref().to_owned(),
selection: self.selection.clone(),
+ text_size: self.text_size,
}
}
}
@@ -63,6 +69,7 @@ impl Preedit {
Preedit {
content: &self.content,
selection: self.selection.clone(),
+ text_size: self.text_size,
}
}
}
@@ -90,13 +97,13 @@ impl InputMethod {
/// let open = InputMethod::Open {
/// position: Point::ORIGIN,
/// purpose: Purpose::Normal,
/// preedit: Some(Preedit { content: "1".to_owned(), selection: None }),
/// };
///
/// let open_2 = InputMethod::Open {
/// position: Point::ORIGIN,
/// purpose: Purpose::Secure,
/// preedit: Some(Preedit { content: "2".to_owned(), selection: None }),
/// };
///
/// let mut ime = InputMethod::Disabled;
@@ -90,13 +97,13 @@ impl InputMethod {
/// position: Point::ORIGIN,
/// purpose: Purpose::Normal,
- /// preedit: Some(Preedit { content: "1".to_owned(), selection: None }),
+ /// preedit: Some(Preedit { content: "1".to_owned(), selection: None, text_size: None }),
/// };
///
@@ -90,13 +97,13 @@ impl InputMethod {
/// position: Point::ORIGIN,
/// purpose: Purpose::Secure,
- /// preedit: Some(Preedit { content: "2".to_owned(), selection: None }),
+ /// preedit: Some(Preedit { content: "2".to_owned(), selection: None, text_size: None }),
/// };
///